@@ -14,8 +14,8 @@ from .. import get_iso_timestamp, get_nexus_filename, log
 from ..nxs_write.NexusWriter import ScanReader, call_writers
 from ..nxs_write.NXclassWriters import write_NXdatetime, write_NXentry, write_NXnote
 from ..tools.VDS_tools import image_vds_writer
-from . import compute_goniometer, read_chip_map
 from .I24_Eiger_params import dset_links, eiger9M_params, goniometer_axes, source
+from .SSX_chip import compute_goniometer, read_chip_map
 
 # Define a logger object and a formatter
 logger = logging.getLogger("nexgen.I24")
@@ -43,6 +43,30 @@ ssx_collect = namedtuple(
     ],
 )
 
+ssx_collect.__doc__ = """Parameters that define a serial collection on I24."""
+ssx_collect.visitpath.__doc__ = "Path to colection directory."
+ssx_collect.filename.__doc__ = "Root of the filename."
+ssx_collect.exp_type.__doc__ = (
+    "Experiment being run. Accepted values for I24: extruder, fixed_target, 3Dgridscan."
+)
+ssx_collect.num_imgs.__doc__ = "Total number of images collected."
+ssx_collect.beam_center.__doc__ = "Beam center position, in pixels."
+ssx_collect.detector_distance.__doc__ = "Distance between sample and detector, in mm."
+ssx_collect.start_time.__doc__ = "Experiment start time."
+ssx_collect.stop_time.__doc__ = "Experiment end time."
+ssx_collect.exposure_time.__doc__ = "Exposure time, in s."
+ssx_collect.transmission.__doc__ = "Attenuator transmission, in %."
+ssx_collect.wavelength.__doc__ = "Wavelength of incident beam."
+ssx_collect.flux.__doc__ = "Total flux."
+ssx_collect.pump_status.__doc__ = "True for a pump-probe experiment, false otherwise."
+ssx_collect.pump_exp.__doc__ = "Pump exposure time, in s."
+ssx_collect.pump_delay.__doc__ = "Pump delay time, in s."
+ssx_collect.chip_info.__doc__ = "For a grid scan, dictionary containing basic chip information. At least it should contain: x/y_start, x/y number of blocks and block size, x/y number of steps and number of exposures."
+ssx_collect.chipmap.__doc__ = (
+    "Path to the chipmap file corresponding to the experiment."
+)
+
+# Define coordinate frame
 coordinate_frame = "mcstas"
 
 # Initialize dictionaries
@@ -218,8 +242,8 @@ def fixed_target(
                 ),
             )
             OSC["omega"] = np.append(OSC["omega"], osc["omega"])
-            TRANSL["sam_y"] = np.append(TRANSL["sam_y"], transl["sam_y"])
-            TRANSL["sam_x"] = np.append(TRANSL["sam_x"], transl["sam_x"])
+            TRANSL["sam_y"] = np.append(TRANSL["sam_y"], np.round(transl["sam_y"], 3))
+            TRANSL["sam_x"] = np.append(TRANSL["sam_x"], np.round(transl["sam_x"], 3))
 
         # Log data
         logger.info("Goniometer information")
@@ -358,10 +382,11 @@ def write_nxs(**ssx_params):
         else Path(ssx_params["chipmap"]).expanduser().resolve(),
     )
 
-    logfile = SSX.visitpath / "nexus_writer.log"
+    logfile = SSX.visitpath / "I24_nxs_writer.log"
     # Configure logging
     log.config(logfile.as_posix())
 
+    # TODO check that detector distance is in mm.
     # Add to dictionaries
     detector["starts"] = [SSX.detector_distance]
     detector["exposure_time"] = SSX.exposure_time
@@ -408,6 +433,21 @@ def write_nxs(**ssx_params):
     master_file = get_nexus_filename(filename[0])
     logger.info("NeXus file will be saved as %s" % master_file)
 
+    logger.info("Detector information")
+    logger.info(f"{detector['description']}")
+    logger.info(
+        f"Sensor made of {detector['sensor_material']} x {detector['sensor_thickness']}"
+    )
+    logger.info(
+        f"Detector is a {detector['image_size'][::-1]} array of {detector['pixel_size']} pixels"
+    )
+    for k in range(len(detector["axes"])):
+        logger.info(
+            f"Detector axis: {detector['axes'][k]} => {detector['starts'][k]}, {detector['types'][k]} on {detector['depends'][k]}"
+        )
+
+    logger.info(f"Recorded beam center is: {SSX.beam_center}.")
+
     # Call correct function for the current experiment
     if SSX.exp_type == "extruder":
         extruder(master_file, filename, SSX, metafile)
