@@ -1,10 +1,10 @@
 """
 Tools for copying the metadata from Tristan NeXus files.
 """
+from __future__ import annotations
 
 import logging
 from pathlib import Path
-from typing import Optional, Union
 
 import h5py
 import numpy as np
@@ -16,8 +16,8 @@ tristan_logger = logging.getLogger("nexgen.CopyTristanNeXus")
 
 
 def single_image_nexus(
-    data_file: Optional[Union[Path, str]],
-    tristan_nexus: Optional[Union[Path, str]],
+    data_file: Path | str,
+    tristan_nexus: Path | str,
     write_mode: str = "x",
 ) -> str:
     """
@@ -71,7 +71,7 @@ def single_image_nexus(
                 # was not moved during the data collection, record the rotation axis
                 # position as a scalar.
                 ax_range = nxs_in["entry/data"][ax][()]
-            nxdata.create_dataset(ax, data=ax_range)
+            nxdata.create_dataset(ax, data=np.array([ax_range]))
             # Write the attributes
             for key, value in ax_attr.items():
                 nxdata[ax].attrs.create(key, value)
@@ -83,8 +83,8 @@ def single_image_nexus(
 
 
 def multiple_images_nexus(
-    data_file: Optional[Union[Path, str]],
-    tristan_nexus: Optional[Union[Path, str]],
+    data_file: Path | str,
+    tristan_nexus: Path | str,
     write_mode: str = "x",
     osc: float = None,
     nbins: int = None,
