@@ -1,9 +1,10 @@
 """
 Define a Metafile object to describe the _meta.h5 file and get the necessary information from it.
 """
+from __future__ import annotations
 
 import re
-from typing import List, Tuple, Union
+from typing import Dict, List, Tuple
 
 import h5py
 
@@ -11,7 +12,7 @@ try:
     # Only for Python version >= 3.8
     from functools import cached_property
 except ImportError:
-    # Compatibility fr earlier Python versions
+    # Compatibility for earlier Python versions
     import functools
 
     def cached_property(func):
@@ -30,7 +31,7 @@ class Metafile:
     def __init__(self, handle: h5py.File):
         self._handle = handle
 
-    def __getitem__(self, key: str) -> Union[h5py.Group, h5py.Dataset]:
+    def __getitem__(self, key: str) -> h5py.Group | h5py.Dataset:
         return self._handle[key]
 
     def __len__(self):
@@ -73,6 +74,28 @@ class DectrisMetafile(Metafile):
                 return True
         return False
 
+    @cached_property
+    def hasConfig(self) -> bool:
+        if "config" in self._handle.keys():
+            return True
+        return False
+
+    def read_config_dset(self) -> Dict:
+        config = eval(self._handle["config"][()])
+        return config
+
+    def get_number_of_images(self) -> int:
+        if self.hasConfig:
+            config = self.read_config_dset()
+            if config["nimages"] >= 1 and config["ntrigger"] == 1:
+                return config["nimages"]
+            elif config["nimages"] == 1 and config["ntrigger"] > 1:
+                # For example a "triggered" data collection
+                return config["ntrigger"]
+        else:
+            _loc = [obj for obj in self.walk if "nimages" in obj]
+            return self.__getitem__(_loc[0])[0]
+
     def get_detector_size(self) -> Tuple:
         # NB. reurns (fast, slow) but data_size in nxs file shoud be recorded (slow, fast)
         # => det_size[::-1]
